
%%%%%%%%%%%%%%%%
define get_count_rate()
%%%%%%%%%%%%%%%%
%!%+
%\function{get_count_rate}
%
%\synopsis{Get background-subtracted count rates}
%\usage{Double_Type = get_count_rate (hist_index);
%\description
%
%       Use this function to retrive background subtracted 
%       countrates (default), countrates or background rates
%       for spectra that have been loaded.
%                   
%       WARNING: This implementation for faked 
%        datasets is experimental!!
%
%\qualifiers{
%
%    tex: additional TeXoutput of CRs, choose this if you need
%         errors
%    bkg: 0 (default: background subtracted CR), 1 (count rates),
%         2 (background count rate)
%    fake: Set this qualifier if you have a faked spectrum and a 
%          faked background (which has not been deleted!); 
%          Assumption: hist_index(bkg) = hist_index(dset) +1 !!
%
%          }
%
%}
% 
%
%
%EXAMPLE
%
%       isis>xray = load_data("data.pha");
%       isis>variable cr = get_count_rate (1 ;tex, bkg=1);
%
%
%\seealso{get_data_counts; TeX_value_pm_error;}
%!%-
{
    variable dset;

    switch(_NARGS)
    { case 1: dset  = (); }
    { help(_function_name()); return; }

    variable bkg = qualifier("bkg", 0);
    variable counts_data, back_file, load_back,counts_back, counts_err, 
    counts_back_err, cr_data, cr_back, expos, cr_sub, cr_sub_err, cr_err, 
    cr_back_err;


    if (qualifier_exists("fake")){
	% Get Background from faked bkg
	back_file = dset+1;
	counts_back = sum(_A(get_data_counts(back_file)).value);

    }

    else 
    {   
	% Load back and get back counts
 	back_file=(get_data_info(dset).bgd_file);
	load_back = load_data(back_file);
	counts_back = sum(_A(get_data_counts(load_back)).value);
	% Delete background
	delete_data(load_back);
    }


    % GET BACKSCALES
    variable db = get_data_backscale(dset);
    variable bb = get_back_backscale(dset);
    variable fac = db/bb;

    counts_back = counts_back*fac;

    % GET SOURCE COUNTS
    counts_data = sum(_A(get_data_counts(dset)).value);
    counts_err = sqrt(counts_data); 
	
    % Get back counts Err

    counts_back_err = sqrt(counts_back);

    % Get background subtracted countrate
    expos = get_data_exposure(dset);

    cr_data = counts_data/expos;
    cr_err = counts_err/expos;

    cr_back = counts_back/expos;
    cr_back_err = counts_back_err/expos;

    cr_sub = cr_data-(cr_back);
    cr_sub_err = sqrt((cr_err)^2-(cr_back_err)^2);
    
    % Check for Qualifier
    variable check_cr;
    
    if (bkg == 0){
	if (qualifier_exists("tex")){
	    vmessage(TeX_value_pm_error(cr_sub, cr_sub-cr_sub_err, 
	    cr_sub+cr_sub_err));
	}
	return cr_sub;
    }
    
    else if (bkg == 1){
	if (qualifier_exists("tex")){
	    vmessage(TeX_value_pm_error(cr_data, cr_data-cr_err, 
	    cr_data+cr_err));
	}
	return cr_data;
    }
    else if (bkg == 2){
	if (qualifier_exists("tex")){
	    vmessage(TeX_value_pm_error(cr_back, cr_back-cr_back_err, 
	    cr_back+cr_back_err));
	}
	return cr_back;
    }
    else {
	vmessage("Wrong Input for Bkg qualifier!");
    }
}  
